@@ -1,2 +1,5 @@
 from reflected import Reflected
-from clonable import Clonable
\ No newline at end of file
+from clonable import Clonable
+
+import filter
+import instor
\ No newline at end of file
